@@ -285,7 +285,8 @@ runActions fu text
   = do x <- noinclude wurl text
        y <- runAction "{{Druckversion Kapitel|" "}}" (chapterAction wurl)
               x
-       z <- runAction "{{print entry|" "}}" (chapterAction2 fu) y
+       v <- runAction "{{Print entry|" "}}" (chapterAction2 fu) y
+       z <- runAction "{{print entry|" "}}" (chapterAction2 fu) v
        a <- runAction "{{Print entry|" "}}" (chapterAction wurl) z
        b <- runAction "{{:" "}}" (includeAction wurl) a
        c <- runAction "{{:" "}}" (qIncludeAction wurl) b
