@@ -28,7 +28,7 @@ makeUrl2 theLemma theHost
               ("action", "history")],
            url_type =
              Absolute
-               (Host{protocol = HTTP False, host = theHost, port = Nothing})})
+               (Host{protocol = HTTP True, host = theHost, port = Nothing})})
  
 makeUrl4 :: String -> [Char]
 makeUrl4 uuu
@@ -49,7 +49,7 @@ makeUrl3 theLemma theHost
       (URL{url_path = "w/index.php", url_params = [("title", theLemma)],
            url_type =
              Absolute
-               (Host{protocol = HTTP False, host = theHost, port = Nothing})})
+               (Host{protocol = HTTP True, host = theHost, port = Nothing})})
  
 deepGet2 :: [Char] -> [Anything a] -> [Anything a]
 deepGet2 tag ll = concat $ map go ll
@@ -101,7 +101,7 @@ simpleContributors theLemma theHost uu st
                                                                                                   mm
                                                                                                 of
                                                                                                   (Just
-                                                                                                     x) -> "http://"
+                                                                                                     x) -> "https://"
                                                                                                              ++
                                                                                                              theHost
                                                                                                                ++
