@@ -4,11 +4,9 @@ module UrlAnalyse
         FullWikiUrl, hostname, url, alternatives, lemma, wikiUrl, geturl,
         parses, geturl2, fullWikiUrlZero, getExpandedPage, getpage2)
        where
-import qualified Network.Browser as Browser
 import Network.HTTP.Conduit
 import Data.ByteString.Lazy.Internal
 import Network.URL as URL
-import Network.HTTP
 import Control.Monad
 import Data.Maybe
 import Data.List.Split
@@ -17,9 +15,14 @@ import Text.XML.HXT.Core
 import Data.Tree.NTree.TypeDefs
 import Codec.Binary.UTF8.String
 import Control.Exception
+import qualified Network.HTTP.Client.Internal as I
+import qualified Data.ByteString.Lazy as L
+import Control.Exception as X
 import qualified Data.ByteString as BStr
 import qualified Data.ByteString.UTF8 as UTF8Str
- 
+import qualified Network.HTTP.Types as T
+import qualified Network.HTTP.Types.Version as V
+import Data.Char
 {-DHUN| This represents the main url of a wiki page. So the url of the wiki page that should be converted to latex. It is a tuple wrapped into the maybe monad, to deal with case in which the url could not be parses. The first element of the tuple is just the main url parser with Network.URL The second element is a list of urls. These URLs are possible base urls for wiki pages. So en.wikipedia.org/wiki/Foobar has got the main url en.wikipedia.org/wiki/Foobar and one of the base urls us en.wikipedia.org/wiki/. Base urls are important since the wiki source related to the main url might include subpage in wiki notation that is [[JohnDow]]. The actual url to look up JohnDow is the baseurl plus JohnDow so that is en.wikipedia.org/wiki/JohnDow Since also images in the commons and similar things are possible, the are usually some baseurls to be looked at. This way the base URl have to be a list. DHUN-}
  
 type WikiUrl = Maybe (URL, [URL])
@@ -38,7 +41,7 @@ fullWikiUrlZero
   = FullWikiUrl{url =
                   URL{URL.url_type =
                         Absolute
-                          (Host{URL.protocol = HTTP False, URL.host = "",
+                          (Host{URL.protocol = HTTP True, URL.host = "",
                                 URL.port = Nothing}),
                       url_path = "", url_params = []},
                 alternatives = [], hostname = "", lemma = ""}
@@ -52,11 +55,11 @@ parses u
  
 {-DHUN| takes a baseurl and a wiki lemma and creates the url under which the wiki source code of the lemma can be retrieved. So the Url en.wikipedia.org/wiki/FoorBar has possible many baseurls. One of which is  en.wikipedia.org/wiki/. The wiki source of the lemma JonDow can be retrieved from the wiki via the url en.wikipedia.org/wiki/Special:Export/JohnDow. Which is just what these function returns. See also documentation on the type 'WikiUrl' on what a baseurl is. DHUN-}
  
-modpath :: String -> URL -> URL
-modpath s u
+modpath :: URL -> URL
+modpath u
   = u{url_path =
-        if p /= [] then p ++ "/Special:Export/" ++ s else
-          "Special:Export/" ++ s}
+        if p /= [] then p ++ "/Special:Export" else
+          "Special:Export"}
   where p = (url_path u)
  
 modpathForExpansion :: URL -> URL
@@ -71,19 +74,69 @@ modpathForExpansion u
  
 geturl :: String -> IO String
 geturl u
-  = Control.Exception.catch
-      (do x <- Browser.browse $
-                 do Browser.setAllowRedirects True
-                    Browser.request $ getRequest u
-          return (rspBody (snd x)))
+  = if u=="" then return ([]) else Control.Exception.catch
+      (do req0 <- parseUrl u
+          let req
+                = ((urlEncodedBody
+                     (map (\ (a, b) -> (UTF8Str.fromString a, UTF8Str.fromString b))
+                        []))
+                    req0) {method=method req0}
+          res <- (withManager $ httpLbs req)`X.catch` statusExceptionHandler
+          print u
+          return ((unpackChars (responseBody res))))
       fun
-  where  
+ where  
         fun :: ErrorCall -> IO String
         fun _ = return ""
+        statusExceptionHandler ::  SomeException -> IO (Network.HTTP.Conduit.Response L.ByteString)
+        statusExceptionHandler _ = (return (I.Response {responseBody=L.empty,responseStatus=T.Status {T.statusCode=200,T.statusMessage=BStr.empty}, responseVersion=V.http09,responseHeaders=[],responseCookieJar=I.CJ [],I.responseClose'=I.ResponseClose (return ())}))
  
+
+geturl2 :: String -> IO BStr.ByteString
+geturl2 u
+  = if u=="" then return (BStr.pack []) else Control.Exception.catch
+      (do req0 <- parseUrl u
+          let req
+                = ((urlEncodedBody
+                     (map (\ (a, b) -> (UTF8Str.fromString a, UTF8Str.fromString b))
+                        []))
+                    req0) {method=method req0}
+          res <- (withManager $ httpLbs req)`X.catch` statusExceptionHandler
+          print u
+          return (BStr.pack (map (fromIntegral.ord)(unpackChars (responseBody res)))))
+      fun
+ where  
+        fun :: ErrorCall -> IO BStr.ByteString
+        fun _ = return (BStr.pack [])
+        statusExceptionHandler ::  SomeException -> IO (Network.HTTP.Conduit.Response L.ByteString)
+        statusExceptionHandler _ = (return (I.Response {responseBody=L.empty,responseStatus=T.Status {T.statusCode=200,T.statusMessage=BStr.empty}, responseVersion=V.http09,responseHeaders=[],responseCookieJar=I.CJ [],I.responseClose'=I.ResponseClose (return ())}))
+
+geturl4 :: String -> String -> IO String
+geturl4 s u
+  = if u=="" then return ([]) else Control.Exception.catch
+      (do req0 <- parseUrl (u++"/"++s)
+          let req
+                = ((urlEncodedBody
+                     (map (\ (a, b) -> (UTF8Str.fromString a, UTF8Str.fromString b))
+                        [("mw-input-pages",s),("curonly","1"),("wpExportTemplates","0"),("wpDownload","1")]))
+                    req0) 
+          print u
+          res <- (withManager (httpLbs req))`X.catch` statusExceptionHandler
+          return ((unpackChars (responseBody res))))
+      fun
+ where  
+        fun :: ErrorCall -> IO String
+        fun _ = return ""
+        statusExceptionHandler ::  SomeException -> IO (Network.HTTP.Conduit.Response L.ByteString)
+        statusExceptionHandler _ = (return (I.Response {responseBody=L.empty,responseStatus=T.Status {T.statusCode=200,T.statusMessage=BStr.empty}, responseVersion=V.http09,responseHeaders=[],responseCookieJar=I.CJ [],I.responseClose'=I.ResponseClose (return ())}))
+
+
+
+
+
 geturl3 :: String -> String -> String -> IO String
 geturl3 u d s
-  = Control.Exception.catch
+  = if u=="" then return ([]) else Control.Exception.catch
       (do req0 <- parseUrl u
           let req
                 = (urlEncodedBody
@@ -91,27 +144,16 @@ geturl3 u d s
                         [("wpInput", d), ("removecomments", "1"), ("removenowiki", "1"),
                          ("generate_xml", "0"), ("contexttitle", s)]))
                     req0
-          res <- withManager $ httpLbs req
+          print u
+          res <- (withManager $ httpLbs req) `X.catch` statusExceptionHandler
           return ((unpackChars (responseBody res))))
       fun
-  where  
+ where  
         fun :: ErrorCall -> IO String
         fun _ = return ""
+        statusExceptionHandler ::  SomeException -> IO (Network.HTTP.Conduit.Response L.ByteString)
+        statusExceptionHandler _ = (return (I.Response {responseBody=L.empty,responseStatus=T.Status {T.statusCode=200,T.statusMessage=BStr.empty}, responseVersion=V.http09,responseHeaders=[],responseCookieJar=I.CJ [],I.responseClose'=I.ResponseClose (return ())}))
  
-geturl2 :: String -> IO BStr.ByteString
-geturl2 u
-  = Control.Exception.catch
-      (do x <- Browser.browse $
-                 do Browser.setAllowRedirects True
-                    Browser.request $
-                      Request{rqURI = rqURI dg, rqMethod = rqMethod dg,
-                              rqHeaders = rqHeaders dg, rqBody = UTF8Str.fromString (rqBody dg)}
-          return (rspBody (snd x)))
-      fun
-  where  
-        fun :: ErrorCall -> IO BStr.ByteString
-        fun _ = return (BStr.pack [])
-        dg = (getRequest u)
  
 {-DHUN| helper function to get the actual wiki source as string out of a part of and xml tree returned by the xml parser. Only used for the function getTextContent DHUN-}
  
@@ -159,7 +201,7 @@ myfun _ = return ()
  
 getpage :: String -> WikiUrl -> IO (Maybe String)
 getpage ss u
-  = do l <- mapM (geturl . unify . exportURL . modpath ss) (parses u)
+  = do l <- mapM ((geturl4 ss ). unify . exportURL . modpath) (parses u)
        ll <- mapM getTextContent2 l
        lll <- return (seq ll ll)
        return $
@@ -168,7 +210,7 @@ getpage ss u
  
 getpage2 :: String -> WikiUrl -> IO (Maybe (String, URL))
 getpage2 ss u
-  = do l <- mapM (geturl . unify . exportURL . modpath ss) (parses u)
+  = do l <- mapM ((geturl4 ss) . unify . exportURL . modpath) (parses u)
        ll <- mapM getTextContent2 l
        lll <- return (seq ll ll)
        return $ (listToMaybe $ concat (map go (zip lll (parses u))))
@@ -199,7 +241,7 @@ unify [] = []
 analyse :: String -> WikiUrl
 analyse s
   = do vv <- v
-       ww <- importURL "http://commons.wikimedia.org/wiki"
+       ww <- importURL "https://commons.wikimedia.org/wiki"
        return (vv, z ++ [ww])
   where v = importURL s
          
